@@ -61,6 +61,8 @@ int gnutls_x509_crt_get_dn(gnutls_x509_crt cert, char *buf,
 	 int *sizeof_buf);
 int gnutls_x509_crt_get_dn_by_oid(gnutls_x509_crt cert, 
 	const char* oid, int indx, char *buf, int *sizeof_buf);
+int gnutls_x509_crt_check_hostname(gnutls_x509_crt cert,
+                                const char *hostname);
 
 int gnutls_x509_crt_get_signature_algorithm(gnutls_x509_crt cert);
 int gnutls_x509_crt_get_version(gnutls_x509_crt cert);
@@ -207,6 +209,8 @@ int gnutls_x509_crt_get_fingerprint(gnutls_x509_crt cert,
 /* Private key handling
  */
 
+/* Flags for the gnutls_x509_privkey_export_pkcs8() function.
+ */
 typedef enum gnutls_privkey_pkcs8_flags {
 	GNUTLS_PKCS8_PLAIN=1,  /* if set the private key will not
 			        * be encrypted.
