@@ -134,8 +134,8 @@ typedef struct gnutls_cipher_entry gnutls_cipher_entry;
  */
 static const gnutls_cipher_entry algorithms[] = {
 	{"3DES 168 CBC", GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8, 0 },
-	{"RIJNDAEL 128 CBC", GNUTLS_CIPHER_RIJNDAEL_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
-	{"RIJNDAEL 256 CBC", GNUTLS_CIPHER_RIJNDAEL_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0 },
+	{"AES 128 CBC", GNUTLS_CIPHER_AES_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
+	{"AES 256 CBC", GNUTLS_CIPHER_AES_256_CBC, 16, 32, CIPHER_BLOCK, 16, 0 },
 	{"TWOFISH 128 CBC", GNUTLS_CIPHER_TWOFISH_128_CBC, 16, 16, CIPHER_BLOCK, 16, 0 },
 	{"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0 },
 	{"ARCFOUR 40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1 },
@@ -268,8 +268,8 @@ typedef struct {
 #define GNUTLS_ANON_DH_ARCFOUR_MD5 { 0x00, 0x18 }
 
  /* rfc3268: */
-#define GNUTLS_ANON_DH_RIJNDAEL_128_CBC_SHA { 0x00, 0x34 }
-#define GNUTLS_ANON_DH_RIJNDAEL_256_CBC_SHA { 0x00, 0x3A }
+#define GNUTLS_ANON_DH_AES_128_CBC_SHA { 0x00, 0x34 }
+#define GNUTLS_ANON_DH_AES_256_CBC_SHA { 0x00, 0x3A }
 /* gnutls private extensions: */
 #define GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA { 0xFF, 0x50 } /* gnutls */
 
@@ -278,17 +278,17 @@ typedef struct {
  ** draft-ietf-tls-srp-02:
  **/
 #define GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA { 0x00, 0x50 }
-#define GNUTLS_SRP_SHA_RIJNDAEL_128_CBC_SHA { 0x00, 0x53 }
-#define GNUTLS_SRP_SHA_RIJNDAEL_256_CBC_SHA { 0x00, 0x56 }
+#define GNUTLS_SRP_SHA_AES_128_CBC_SHA { 0x00, 0x53 }
+#define GNUTLS_SRP_SHA_AES_256_CBC_SHA { 0x00, 0x56 }
 
 #define GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA { 0x00, 0x51 }
 #define GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA { 0x00, 0x52 }
 
-#define GNUTLS_SRP_SHA_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x54 }
-#define GNUTLS_SRP_SHA_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x55 }
+#define GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA { 0x00, 0x54 }
+#define GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA { 0x00, 0x55 }
 
-#define GNUTLS_SRP_SHA_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x57 }
-#define GNUTLS_SRP_SHA_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x58 }
+#define GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA { 0x00, 0x57 }
+#define GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA { 0x00, 0x58 }
 
 /** RSA 
  **/
@@ -300,8 +300,8 @@ typedef struct {
 
 /* rfc3268: 
  */
-#define GNUTLS_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x2F }
-#define GNUTLS_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x35 }
+#define GNUTLS_RSA_AES_128_CBC_SHA { 0x00, 0x2F }
+#define GNUTLS_RSA_AES_256_CBC_SHA { 0x00, 0x35 }
 
 /* gnutls private extensions: 
  */
@@ -323,8 +323,8 @@ typedef struct {
 
 /* rfc3268: 
  */
-#define GNUTLS_DHE_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x38 }
-#define GNUTLS_DHE_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x32 }
+#define GNUTLS_DHE_DSS_AES_256_CBC_SHA { 0x00, 0x38 }
+#define GNUTLS_DHE_DSS_AES_128_CBC_SHA { 0x00, 0x32 }
 
 
 /** DHE RSA 
@@ -337,8 +337,8 @@ typedef struct {
 
 /* rfc3268: 
  */
-#define GNUTLS_DHE_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x33 }
-#define GNUTLS_DHE_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x39 }
+#define GNUTLS_DHE_RSA_AES_128_CBC_SHA { 0x00, 0x33 }
+#define GNUTLS_DHE_RSA_AES_256_CBC_SHA { 0x00, 0x39 }
 
 #define CIPHER_SUITES_COUNT sizeof(cs_algorithms)/sizeof(gnutls_cipher_suite_entry)-1
 
@@ -350,11 +350,11 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_ANON_DH,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_ANON_DH,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA,
 				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_ANON_DH,
@@ -364,11 +364,11 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_SRP,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA,
@@ -379,20 +379,20 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_SRP_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_SRP_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_SRP_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_SRP_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
 	/* DHE_DSS */
@@ -405,11 +405,11 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_DHE_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_DHE_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_DSS,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
 
 	/* DHE_RSA */
@@ -419,11 +419,11 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_DHE_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_DHE_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_DHE_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_DHE_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_DHE_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
 
 	/* RSA */
@@ -444,11 +444,11 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_SHA,
 				  GNUTLS_CIPHER_3DES_CBC,
 				  GNUTLS_KX_RSA, GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_128_CBC_SHA,
+				  GNUTLS_CIPHER_AES_128_CBC, GNUTLS_KX_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_AES_256_CBC_SHA,
+				  GNUTLS_CIPHER_AES_256_CBC, GNUTLS_KX_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_SSL3),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_TWOFISH_128_CBC_SHA,
 				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_RSA,
