@@ -353,13 +353,13 @@ inline static int cpydata(const uint8 * data, int data_size, uint8 ** result)
  * The result_size is the return value
  */
 #define ENDSTR "-----\n"
-#define ENDSTR2 "-----\r\n"
+#define ENDSTR2 "-----\r"
 int _gnutls_fbase64_decode( const opaque* header, const opaque * data, size_t data_size,
 			   uint8 ** result)
 {
 	int ret;
-	const char top[] = "-----BEGIN ";
-	const char bottom[] = "\n-----END ";
+	static const char top[] = "-----BEGIN ";
+	static const char bottom[] = "\n-----END ";
 	uint8 *rdata;
 	int rdata_size;
 	uint8 *kdata;
