@@ -5,29 +5,30 @@
 #include <gnutls/extra.h>
 #include <gnutls/x509.h>
 #include <time.h>
+#include <common.h>
 
 #define TEST_STRING
 
 int xml = 0;
-void print_cert_info(gnutls_session session);
 
 #define PRINTX(x,y) if (y[0]!=0) printf(" #   %s %s\n", x, y)
 #define PRINT_PGP_NAME(X) PRINTX( "NAME:", X.name); \
 	PRINTX( "EMAIL:", X.email)
 
-static const char *my_ctime(time_t * tv)
+static const char *my_ctime(const time_t * tv)
 {
 	static char buf[256];
 	struct tm *tp;
 
-	tp = localtime(tv);
-	strftime(buf, sizeof buf, "%a %b %e %H:%M:%S %Z %Y\n", tp);
+	if ( ( (tp = localtime(tv)) == NULL ) ||
+	     (!strftime(buf, sizeof buf, "%a %b %e %H:%M:%S %Z %Y\n", tp)) )
+		strcpy(buf, "unknown"); /* make sure buf text isn't garbage */
 
 	return buf;
 
 }
 
-void print_x509_info(gnutls_session session)
+void print_x509_info(gnutls_session session, const char* hostname)
 {
 	gnutls_x509_crt crt;
 	const gnutls_datum *cert_list;
@@ -62,13 +63,25 @@ void print_x509_info(gnutls_session session)
 		    gnutls_x509_crt_import(crt, &cert_list[j],
 					   GNUTLS_X509_FMT_DER);
 		if (ret < 0) {
-			fprintf(stderr, "Decoding error: %s\n",
-				gnutls_strerror(ret));
+			const char* str = gnutls_strerror(ret);
+			if (str == NULL) str = "(unknown)";
+			fprintf(stderr, "Decoding error: %s\n", str);
 			return;
 		}
 
-
 		printf(" - Certificate[%d] info:\n", j);
+		
+		if (j==0 && hostname != NULL) { /* Check the hostname of the first certificate
+		             * if it matches the name of the host we
+		             * connected to.
+		             */
+		             if (gnutls_x509_crt_check_hostname( crt, hostname)==0) {
+		             	printf(" # The hostname in the certificate does NOT match '%s'.\n", hostname);
+		             } else {
+		             	printf(" # The hostname in the certificate matches '%s'.\n", hostname);
+		             }
+		}
+
 
 		if (xml) {
 #ifdef ENABLE_PKI
@@ -76,8 +89,10 @@ void print_x509_info(gnutls_session session)
 
 			ret = gnutls_x509_crt_to_xml( crt, &xml_data, 0);
 			if (ret < 0) {
+				const char* str = gnutls_strerror(ret);
+				if (str == NULL) str = "(unknown)";
 				fprintf(stderr, "XML encoding error: %s\n",
-					gnutls_strerror(ret));
+					str);
 				return;
 			}
 			
@@ -111,7 +126,9 @@ void print_x509_info(gnutls_session session)
 			digest_size = sizeof(digest);
 			if ((ret=gnutls_x509_crt_get_fingerprint(crt, GNUTLS_DIG_MD5, digest, &digest_size))
 			    < 0) {
-			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", gnutls_strerror(ret));
+				const char* str = gnutls_strerror(ret);
+				if (str == NULL) str = "(unknown)";
+			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", str);
 			} else {
 				print = printable;
 				for (i = 0; i < digest_size; i++) {
@@ -268,10 +285,12 @@ void print_cert_vrfy(gnutls_session session)
 		printf("- Peer's certificate is trusted\n");
 	if (status & GNUTLS_CERT_CORRUPTED)
 		printf("- Peer's certificate is corrupted\n");
+		
+	
 
 }
 
-int print_info(gnutls_session session)
+int print_info(gnutls_session session, const char* hostname)
 {
 	const char *tmp;
 	gnutls_credentials_type cred;
@@ -317,7 +336,7 @@ int print_info(gnutls_session session)
 			}
 		}
 
-		print_cert_info(session);
+		print_cert_info(session, hostname);
 
 		print_cert_vrfy(session);
 
@@ -349,17 +368,19 @@ int print_info(gnutls_session session)
 	tmp = gnutls_compression_get_name(gnutls_compression_get(session));
 	printf("- Compression: %s\n", tmp);
 
+	fflush (stdout);
+
 	return 0;
 }
 
-void print_cert_info(gnutls_session session)
+void print_cert_info(gnutls_session session, const char* hostname)
 {
 
 	printf("- Certificate type: ");
 	switch (gnutls_certificate_type_get(session)) {
 	case GNUTLS_CRT_X509:
 		printf("X.509\n");
-		print_x509_info(session);
+		print_x509_info(session, hostname);
 		break;
 	case GNUTLS_CRT_OPENPGP:
 		printf("OpenPGP\n");
@@ -384,7 +405,7 @@ void print_list(void)
 	printf(", SSL3.0\n");
 
 	printf("Ciphers:");
-	printf(" RIJNDAEL-128-CBC");
+	printf(" AES-128-CBC");
 	printf(", TWOFISH-128-CBC");
 	printf(", 3DES-CBC");
 	printf(", ARCFOUR\n");
@@ -448,9 +469,9 @@ void parse_ciphers(char **ciphers, int nciphers, int *cipher_priority)
 
 	if (ciphers != NULL && nciphers > 0) {
 		for (j = i = 0; i < nciphers; i++) {
-			if (strncasecmp(ciphers[i], "RIJ", 3) == 0)
+			if (strncasecmp(ciphers[i], "AES", 3) == 0)
 				cipher_priority[j++] =
-				    GNUTLS_CIPHER_RIJNDAEL_128_CBC;
+				    GNUTLS_CIPHER_AES_128_CBC;
 			if (strncasecmp(ciphers[i], "TWO", 3) == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_TWOFISH_128_CBC;
