@@ -3,9 +3,13 @@
 
 #include <gnutls/gnutls.h>
 
-int print_info( gnutls_session state);
-void print_cert_info( gnutls_session state);
-int print_list(void);
+/* the number of elements in the priority structures.
+ */
+#define PRI_MAX 16
+
+int print_info( gnutls_session state, const char* hostname);
+void print_cert_info( gnutls_session state, const char* hostname);
+void print_list(void);
 
 void parse_comp( char** comp, int ncomp, int* comp_priority);
 void parse_kx( char** kx, int nkx, int* kx_priority);
